@@ -2,7 +2,8 @@
 from typing import Union
 
 import git_portfolio.config_manager as cm
-import git_portfolio.github_manager as ghm
+import git_portfolio.domain.gh_connection_settings as gcs
+import git_portfolio.github_service as ghs
 import git_portfolio.prompt as p
 import git_portfolio.response_objects as res
 import git_portfolio.use_cases.config_repos_use_case as cr
@@ -11,17 +12,21 @@ import git_portfolio.use_cases.config_repos_use_case as cr
 class ConfigInitUseCase:
     """Gitp config initialization use case."""
 
-    def __init__(
-        self, config_manager: cm.ConfigManager, github_manager: ghm.GithubManager
-    ) -> None:
+    def __init__(self, config_manager: cm.ConfigManager) -> None:
         """Initializer."""
         self.config_manager = config_manager
-        self.github_manager = github_manager
 
-    def execute(self) -> Union[res.ResponseFailure, res.ResponseSuccess]:
+    def execute(
+        self, request: gcs.GhConnectionSettings
+    ) -> Union[res.ResponseFailure, res.ResponseSuccess]:
         """Initialize app configuration."""
-        self.github_manager.set_github_account()
-        repo_names = self.github_manager.get_repo_names()
+        try:
+            new_github_service = ghs.GithubService(request)
+        except AttributeError:
+            return res.ResponseFailure.build_parameters_error()
+        except ConnectionError:
+            return res.ResponseFailure.build_system_error()
+        repo_names = new_github_service.get_repo_names()
         selected_repos = p.InquirerPrompter.select_repos(repo_names)
         cr.ConfigReposUseCase(self.config_manager).execute(selected_repos)
         return res.ResponseSuccess("gitp successfully configured.")
